## $Id: catalog.py 12762 2015-03-14 13:49:29Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Components to help cataloging and searching payments.
"""
import grok
from hurry.query import Eq, Text
from hurry.query.query import Query
from zope.catalog.interfaces import ICatalog
from zope.component import queryUtility
from waeup.ikoba.interfaces import ICompany
from waeup.ikoba.payments.interfaces import (
    IPayment, IPayable
    )
from waeup.ikoba.payments.payment import (
    find_payable_from_payable_id
    )


def search(query=None, searchtype=None):
    hitlist = []
    # Temporary solution to display all payments added
    if query == '*':
        cat = queryUtility(ICatalog, name='payments_catalog')
        results = cat.searchResults(payment_id=(None, None))
    else:
        results = Query().searchResults(
            Eq(('payments_catalog', searchtype), query))
    hitlist = []
    for payment in results:
        payable_object = find_payable_from_payable_id(payment.payable_id)
        if payable_object is not None:
            payable = IPayable(payable_object)
        else:
            payable = None
        hitlist.append((payment, payable, payable_object))
    return hitlist


class PaymentIndexes(grok.Indexes):
    """A catalog for all payments.
    """
    grok.site(ICompany)
    grok.name('payments_catalog')
    grok.context(IPayment)

    payment_id = grok.index.Field(attribute='payment_id')
    payer_id = grok.index.Field(attribute='payer_id')
    payable_id = grok.index.Field(attribute='payable_id')
    state = grok.index.Field(attribute='state')
    amount = grok.index.Field(attribute='amount')
